"use client" // Required for using hooks like useAuth and useRouter

import Link from "next/link"
import { useRouter } from "next/navigation" // Import useRouter
import { useAuth } from "@/contexts/auth-context"
import { useLanguage } from "@/contexts/language-context" // Import useLanguage
import { ThemeToggle } from "@/components/theme-toggle"
import { Button } from "@/components/ui/button"
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar"
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu"
import { ShoppingBasket, LogIn, LogOut, UserIcon, Loader2 } from "lucide-react" // Using a relevant icon
import { USFlag, GRFlag } from "@/components/flags" // Import flag components
import { motion } from "framer-motion"

export function Navbar() {
  const { user, loading, signOut } = useAuth()
  const { language, setLanguage, t } = useLanguage() // Get language state and setter
  const router = useRouter() // Initialize router

  const handleSignOut = async () => {
    await signOut()
    // router.push('/auth'); // Optionally redirect after sign out
  }

  const handleSignIn = () => {
    router.push("/auth") // Navigate to the authentication page
  }

  // Helper to get initials from display name
  const getInitials = (name: string | null | undefined): string => {
    if (!name) return ""
    const names = name.split(" ")
    if (names.length === 1) return names[0].charAt(0).toUpperCase()
    return (names[0].charAt(0) + names[names.length - 1].charAt(0)).toUpperCase()
  }

  return (
    <header className="sticky top-0 z-40 w-full border-b bg-white dark:bg-slate-950 shadow-sm">
      <div className="container mx-auto flex h-16 items-center justify-between px-4">
        <Link href="/" className="flex items-center space-x-2">
          <motion.div whileHover={{ rotate: [0, -10, 10, -10, 0], transition: { duration: 0.5 } }}>
            <ShoppingBasket className="h-6 w-6 text-emerald-600 dark:text-emerald-500" />
          </motion.div>
          <span className="text-lg font-bold text-emerald-600 dark:text-emerald-500">{t("appName")}</span>
        </Link>
        <div className="flex items-center space-x-2 md:space-x-3">
          <DropdownMenu>
            <DropdownMenuTrigger asChild>
              <Button
                variant="outline"
                size="icon"
                className="h-9 w-9 border-slate-200 dark:border-slate-800 bg-white dark:bg-slate-950 hover:bg-slate-100 dark:hover:bg-slate-800 overflow-hidden"
              >
                <motion.div
                  key={language}
                  initial={{ y: -20, opacity: 0 }}
                  animate={{ y: 0, opacity: 1 }}
                  exit={{ y: 20, opacity: 0 }}
                  transition={{ duration: 0.2 }}
                  className="h-5 w-5"
                >
                  {language === "en" ? <USFlag className="h-5 w-5" /> : <GRFlag className="h-5 w-5" />}
                </motion.div>
                <span className="sr-only">Change language</span>
              </Button>
            </DropdownMenuTrigger>
            <DropdownMenuContent align="end" className="min-w-[8rem] border-slate-200 dark:border-slate-700">
              <DropdownMenuItem
                onClick={() => setLanguage("en")}
                className={`flex items-center gap-2 ${language === "en" ? "bg-slate-100 dark:bg-slate-800" : ""}`}
              >
                <USFlag className="h-4 w-4" />
                <span>English</span>
                {language === "en" && (
                  <motion.div
                    initial={{ scale: 0 }}
                    animate={{ scale: 1 }}
                    className="ml-auto h-1.5 w-1.5 rounded-full bg-emerald-500"
                  />
                )}
              </DropdownMenuItem>
              <DropdownMenuItem
                onClick={() => setLanguage("el")}
                className={`flex items-center gap-2 ${language === "el" ? "bg-slate-100 dark:bg-slate-800" : ""}`}
              >
                <GRFlag className="h-4 w-4" />
                <span>Ελληνικά</span>
                {language === "el" && (
                  <motion.div
                    initial={{ scale: 0 }}
                    animate={{ scale: 1 }}
                    className="ml-auto h-1.5 w-1.5 rounded-full bg-emerald-500"
                  />
                )}
              </DropdownMenuItem>
            </DropdownMenuContent>
          </DropdownMenu>

          <ThemeToggle />

          {loading ? (
            <div className="h-9 w-9 flex items-center justify-center">
              <Loader2 className="h-5 w-5 animate-spin text-emerald-500" />
            </div>
          ) : user ? (
            <DropdownMenu>
              <DropdownMenuTrigger asChild>
                <Button variant="ghost" className="relative h-9 w-9 rounded-full p-0 overflow-hidden">
                  <Avatar className="h-9 w-9 border-2 border-emerald-100 dark:border-emerald-900">
                    <AvatarImage src={user.photoURL ?? undefined} alt={user.displayName ?? "User"} />
                    <AvatarFallback className="bg-emerald-100 text-emerald-700 dark:bg-emerald-900 dark:text-emerald-300">
                      {getInitials(user.displayName)}
                    </AvatarFallback>
                  </Avatar>
                </Button>
              </DropdownMenuTrigger>
              <DropdownMenuContent className="w-56" align="end" forceMount>
                <DropdownMenuLabel className="font-normal">
                  <div className="flex flex-col space-y-1">
                    <p className="text-sm font-medium leading-none">{user.displayName ?? "User"}</p>
                    <p className="text-xs leading-none text-muted-foreground">{user.email ?? "No email provided"}</p>
                  </div>
                </DropdownMenuLabel>
                <DropdownMenuSeparator />
                <DropdownMenuItem
                  onClick={() => router.push("/profile")}
                  className="cursor-pointer hover:bg-slate-100 dark:hover:bg-slate-800"
                >
                  <UserIcon className="mr-2 h-4 w-4 text-emerald-500" />
                  <span>{t("profile")}</span>
                </DropdownMenuItem>
                <DropdownMenuSeparator />
                <DropdownMenuItem
                  onClick={handleSignOut}
                  className="cursor-pointer hover:bg-slate-100 dark:hover:bg-slate-800"
                >
                  <LogOut className="mr-2 h-4 w-4 text-emerald-500" />
                  <span>{t("logout")}</span>
                </DropdownMenuItem>
              </DropdownMenuContent>
            </DropdownMenu>
          ) : (
            <Button
              variant="outline"
              size="sm"
              onClick={handleSignIn}
              className="border-emerald-200 bg-emerald-50 hover:bg-emerald-100 text-emerald-700 dark:border-emerald-800 dark:bg-emerald-900/20 dark:hover:bg-emerald-900/30 dark:text-emerald-400"
            >
              <LogIn className="mr-1 h-4 w-4" />
              <span className="hidden sm:inline">{t("login")}</span>
            </Button>
          )}
        </div>
      </div>
    </header>
  )
}
